@@ -129,6 +129,22 @@ function task_install_source_deb_systemd {
     task postinst_deb
 }
 
+# install docs for debian based systems
+function task_install_docs_deb {
+  if [ -d ext/docs ]; then
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb"
+  fi
+}
+
+# install docs for rpm based systems
+function task_install_docs_rpm {
+  if [ -d ext/docs ]; then
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb-5.1.1"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb-5.1.1"
+  fi
+}
+
 # Install the ezbake package software. This step is used during RPM &
 # Debian packaging during the 'install' phases.
 function task_install {
@@ -179,10 +195,12 @@ fi
 
 function task_install_redhat {
     task install
+    task install_docs_rpm
 }
 
 function task_install_deb {
     task install
+    task install_docs_deb
 }
 
 
