@@ -11,6 +11,16 @@
             [puppetlabs.kitchensink.core :as kitchensink]
             [schema.core :as s]))
 
+(defn get-metric [base-url metric-name]
+  (let [url (str (utils/base-url->str base-url)
+                 "/mbeans/"
+                 (java.net.URLEncoder/encode metric-name "UTF-8"))]
+    (:body
+     (http-client/get url {:throw-exceptions false
+                            :content-type :json
+                            :character-encoding "UTF-8"
+                            :accept :json}))) )
+
 (defn-validated submit-command-via-http!
   "Submits `payload` as a valid command of type `command` and
    `version` to the PuppetDB instance specified by `host` and
@@ -31,8 +41,8 @@
     timeout]
    (let [body (json/generate-string payload)
          url (str (utils/base-url->str base-url)
-                  (format "?command=%s&version=%s&certname=%s"
-                          (str/replace command #" " "_") version certname)
+                  (format "?command=%s&version=%s&certname=%s&producer-timestamp=%s"
+                          (str/replace command #" " "_") version certname (System/currentTimeMillis))
                   (when timeout (format "&secondsToWaitForCompletion=%s" timeout)))]
      (http-client/post url {:body body
                             :throw-exceptions false
