@@ -1,6 +1,8 @@
 (ns puppetlabs.puppetdb.http.command
   (:require [clojure.set :as set]
             [puppetlabs.puppetdb.command.constants :refer [command-names]]
+            [puppetlabs.puppetdb.utils :refer [content-encoding->file-extension
+                                               supported-content-encodings]]
             [puppetlabs.trapperkeeper.core :refer [defservice]]
             [clojure.string :as str]
             [clojure.tools.logging :as log]
@@ -15,7 +17,10 @@
             [puppetlabs.comidi :as cmdi]
             [ring.util.request :as request]
             [schema.core :as s]
-            [slingshot.slingshot :refer [try+ throw+]])
+            [slingshot.slingshot :refer [try+ throw+]]
+            [puppetlabs.i18n.core :refer [trs tru]]
+            [puppetlabs.puppetdb.time :as pdbtime]
+            [puppetlabs.puppetdb.utils :as utils])
   (:import [org.apache.commons.io IOUtils]
            [org.apache.commons.fileupload.util LimitedInputStream]))
 
@@ -115,7 +120,8 @@
             (s/required-key "certname") s/Str
             (s/required-key "received") s/Str
             (s/optional-key "secondsToWaitForCompletion") s/Str
-            (s/optional-key "checksum") s/Str}
+            (s/optional-key "checksum") s/Str
+            (s/optional-key "producer-timestamp") s/Str}
    :body java.io.InputStream
    s/Any s/Any})
 
@@ -133,13 +139,14 @@
 
 (defn-validated ^:private normalize-old-request
   [{:keys [params body] :as req} :- old-request-schema]
-  (log/warn (str "Unable to stream command posted without parameters"
-                 " (loading into RAM)"))
+  (log/warn (trs "Unable to stream command posted without parameters (loading into RAM)"))
   (if-not body
-    (http/error-response "Empty application/json POST body")
+    (http/error-response
+     (tru "Empty application/json POST body"))
     (let [body (json/parse-strict (:body req))]
       (if (empty? body)
-        (http/error-response "Empty application/json POST body")
+        (http/error-response
+         (tru "Empty application/json POST body"))
         (do
           (s/validate {(s/required-key "command") s/Str
                        (s/required-key "version") s/Int
@@ -181,7 +188,7 @@
       (java.io.ByteArrayInputStream. (.getBytes body "UTF-8"))
 
       :else
-      (throw (Exception. (str "Unexpected body type: " (class body)))))
+      (throw (Exception. (tru "Unexpected body type: {0}" (class body)))))
     (cond
       (instance? java.io.InputStream body)
       (restrained-drained-stream body (long max-command-size))
@@ -194,12 +201,12 @@
         (java.io.ByteArrayInputStream. (.getBytes body "UTF-8")))
 
       :else
-      (throw (Exception. (str "Unexpected body type: " (class body)))))))
+      (throw (Exception. (tru "Unexpected body type: {0}" (class body)))))))
 
 (defn- enqueue-command-handler
   "Enqueues the command in request and returns a UUID"
   [enqueue-fn max-command-size]
-  (fn [{:keys [body params] :as request}]
+  (fn [{:keys [body params headers]}]
     ;; For now body will be in-memory, but eventually may be a stream.
     (try+
      (let [uuid (kitchensink/uuid)
@@ -211,13 +218,17 @@
            submit-params (if-let [v (submit-params "version")]
                            (update submit-params "version" str)
                            submit-params)
+           compression (content-encoding->file-extension
+                        (get headers "content-encoding"))
            ;; Replace read-body when our queue supports streaming
            do-submit (fn [command-callback]
                        (enqueue-fn
                         (get submit-params "command")
                         (Integer/parseInt (get submit-params "version"))
                         (get submit-params "certname")
+                        (pdbtime/from-string (get submit-params "producer-ts"))
                         (stream-with-max-check body max-command-size)
+                        compression
                         command-callback))]
 
        (if (some-> completion-timeout-ms pos?)
@@ -228,7 +239,7 @@
            (do-submit identity)
            (http/json-response {:uuid (kitchensink/uuid)}))))
      (catch (= ::body-stream-overflow %) _
-       (http/error-response "Command size exceeds max-command-size"
+       (http/error-response (tru "Command size exceeds max-command-size")
                             http/status-entity-too-large)))))
 
 (defn- add-received-param
@@ -257,9 +268,10 @@
       add-received-param ;; must be (temporally) after validate-query-params
       ;; The checksum here is vestigial.  It is no longer checked
       (mid/validate-query-params {:optional ["checksum" "secondsToWaitForCompletion"
-                                             "certname" "command" "version"]})
+                                             "certname" "command" "version" "producer-timestamp"]})
       mid/verify-accepts-json
       (mid/verify-content-type ["application/json"])
+      (mid/verify-content-encoding utils/supported-content-encodings)
       (mid/fail-when-payload-too-large reject-large-commands? max-command-size)
       (mid/wrap-with-metrics (atom {}) http/leading-uris)
       (mid/wrap-with-globals get-shared-globals)))
