@@ -1,5 +1,6 @@
 (ns puppetlabs.puppetdb.scf.storage-utils
-  (:require [clojure.java.jdbc :as sql]
+  (:require [cheshire.factory :refer [*json-factory*]]
+            [clojure.java.jdbc :as sql]
             [clojure.tools.logging :as log]
             [honeysql.core :as hcore]
             [honeysql.format :as hfmt]
@@ -12,13 +13,15 @@
             [puppetlabs.kitchensink.core :as kitchensink]
             [schema.core :as s]
             [puppetlabs.i18n.core :refer [trs]])
-  (:import [org.postgresql.util PGobject]))
+  (:import [java.sql Connection]
+           [java.util UUID]
+           [org.postgresql.util PGobject]))
 
 ;; SCHEMA
 
 (defn array-to-param
   [col-type java-type values]
-  (.createArrayOf (:connection (jdbc/db))
+  (.createArrayOf ^Connection (:connection (jdbc/db))
                   col-type
                   (into-array java-type values)))
 
@@ -43,7 +46,7 @@
 ;; FUNCTIONS
 (defn db-metadata-fn
   []
-  (let [db-metadata (.getMetaData (:connection (jdbc/db)))]
+  (let [db-metadata (.getMetaData ^Connection (:connection (jdbc/db)))]
     {:database (.getDatabaseProductName db-metadata)
      :version [(.getDatabaseMajorVersion db-metadata)
                (.getDatabaseMinorVersion db-metadata)]}))
@@ -51,24 +54,6 @@
 (def db-metadata
   (delay (db-metadata-fn)))
 
-(pls/defn-validated db-version? :- s/Bool
-  "Returns true if the version list you pass matches the version of the current
-   database."
-  [version :- db-version]
-  (= (:version @db-metadata) version))
-
-(pls/defn-validated db-version-older-than? :- s/Bool
-  "Returns true if the current database version is older than the version list
-   you pass it."
-  [version :- db-version]
-  (neg? (compare (:version @db-metadata) version)))
-
-(pls/defn-validated db-version-newer-than? :- s/Bool
-  "Returns true if the current database version is newer than the version list
-   you pass it."
-  [version :- db-version]
-  (pos? (compare (:version @db-metadata) version)))
-
 (defn sql-current-connection-table-names
   "Returns the names of all of the tables in the public schema of the
   current connection's database.  This is most useful for debugging /
@@ -148,13 +133,30 @@
        (= (:relname (first results))
           index))))
 
+(pls/defn-validated constraint-exists? :- s/Bool
+  ([table :- s/Str
+    constraint :- s/Str]
+   (let [schema (current-schema)]
+     (constraint-exists? schema table constraint)))
+
+  ([schema :- s/Str
+    table :- s/Str
+    constraint :- s/Str]
+   (let [query (str "select count(*)"
+                    "  from information_schema.constraint_column_usage"
+                    "  where table_schema = ?"
+                    "  and table_name = ?"
+                    "  and constraint_name = ?")
+         results (jdbc/query-to-vec [query schema table constraint])]
+     (pos? (:count (first results))))))
+
 (defn to-jdbc-varchar-array
   "Takes the supplied collection and transforms it into a
   JDBC-appropriate VARCHAR array."
   [coll]
   (->> coll
        (into-array Object)
-       (.createArrayOf (:connection (jdbc/db)) "varchar")))
+       (.createArrayOf ^Connection (:connection (jdbc/db)) "varchar")))
 
 (defn legacy-sql-regexp-match
   "Returns the SQL for performing a regexp match."
@@ -253,16 +255,16 @@
     (sql/execute! db ["vacuum analyze"] {:transaction? false})))
 
 (defn parse-db-hash
-  [db-hash]
+  [^PGobject db-hash]
   (clojure.string/replace (.getValue db-hash) "\\x" ""))
 
 (defn parse-db-uuid
-  [db-uuid]
+  [^UUID db-uuid]
   (.toString db-uuid))
 
 (pls/defn-validated parse-db-json
   "Produce a function for parsing an object stored as json."
-  [db-json :- (s/maybe (s/cond-pre s/Str PGobject))]
+  [^PGobject db-json :- (s/maybe (s/cond-pre s/Str PGobject))]
   (some-> db-json .getValue (json/parse-string true)))
 
 (pls/defn-validated str->pgobject :- PGobject
@@ -290,11 +292,12 @@
     (str->pgobject "json" json-str)))
 
 (defn munge-jsonb-for-storage
-  "Prepare a clojure object for storage depending on db type."
+  "Prepare a clojure object for storage.  Rewrite all null (\\u0000)
+  characters to the replacement character (\\ufffd) because Postgres
+  cannot handle them in its JSON values."
   [value]
-  (let [json-str (-> (json/generate-string value)
-                     (.replaceAll "\\\\u0000" "\\\ufffd"))]
-    (str->pgobject "jsonb" json-str)))
+  (binding [*json-factory* json/null-replacing-json-factory]
+    (str->pgobject "jsonb" (json/generate-string value))))
 
 (defn db-up?
   [db-spec]
